from pathlib import Path

import pytest


@pytest.fixture(scope="session", name="io_dir")
def fixture_io_dir(fixtures_dir: Path) -> Path:
    """Return the path to the io dir."""
    return Path(fixtures_dir, "io")


@pytest.fixture(scope="session", name="example_yaml_path")
def fixture_example_yaml_path(io_dir: Path) -> Path:
    """Return the path to a example YAML file."""
    return Path(io_dir, "example_yaml.yaml")



from pathlib import Path
from typing import Any

from trailblazer.constants import FileFormat
from trailblazer.io.yaml import read_yaml


class ReadFile:
    """Reading file using different methods."""

    read_file = {
        FileFormat.YAML: read_yaml,
    }

    @classmethod
    def get_content_from_file(cls, file_format: str, file_path: Path) -> Any:
        """Read file using file format dispatch table."""
        return cls.read_file[file_format](file_path=file_path)
